@@ -3,7 +3,7 @@ package Sort::Sub::pod_section_ala_perlancar;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-22'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.090'; # VERSION
+our $VERSION = '0.091'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,6 +14,7 @@ our $SORT_SPEC = [
     # the sections from the original (forked) module, and the XXX sections are
     # for the new module (the fork).
 
+
     # preamble
     'NAME',
     'SPECIFICATION VERSION',
@@ -21,40 +22,51 @@ our $SORT_SPEC = [
     'DEPRECATION NOTICE',
     'SYNOPSIS', 'ORIGINAL SYNOPSIS',
 
+
     # main content
     'DESCRIPTION', 'ORIGINAL DESCRIPTION',
 
+
     # Acme::CPANModules::*
     "ACME::CPANMODULES ENTRIES",
     "ACME::CPANMODULES FEATURE COMPARISON MATRIX",
 
+
     # Bencher::Scenario::*
     'BENCHMARKED MODULES',
     'BENCHMARK PARTICIPANTS',
     'BENCHMARK DATASETS',
     'SAMPLE BENCHMARK RESULTS',
 
+
     # everything else that are uncategorized go here
     sub { 1 },
 
+
     # reference section
     'FUNCTIONS',
     'ATTRIBUTES',
     'METHODS',
 
+
     # reference section (CLI)
     'SUBCOMMANDS',
     'OPTIONS',
 
-    'IMPLEMENTATION NOTES', # from freebsd
+
+    # from bsd
+    'IMPLEMENTATION NOTES',
+
 
     # other content (CLI)
     'COMPLETION',
 
+
     # FAQ (after all content & references)
     'FAQ', 'ORIGINAL FAQ',
     'FAQS', 'ORIGINAL FAQS',
 
+
     # links/pointers (CLI)
     'CONFIGURATION FILE',
     'CONFIGURATION FILES',
@@ -62,28 +74,41 @@ our $SORT_SPEC = [
     'ENVIRONMENT VARIABLES',
     'FILES',
 
-    'EXIT STATUS', # from freebsd
 
-    'EXAMPLES', # from freebsd
+    # exit status, diagnostics, errors. from bsd
+    'EXIT STATUS',
+    'DIAGNOSTICS',
+    # RETURN VALUE # for syscall
+    # ERRORS # for syscall
+
+
+    # examples, from bsd
+    'EXAMPLES',
+
 
     # todos
     'TODO', 'ORIGINAL TODO',
     'TODOS', 'ORIGINAL TODOS',
 
-    # links/pointers/extra information
-    'HISTORY', 'ORIGINAL HISTORY',
+
+    # links
     'HOMEPAGE', 'ORIGINAL HOMEPAGE',
     'SOURCE', 'ORIGINAL SOURCE',
-    'BUGS', 'ORIGINAL BUGS',
-    'GOTCHAS',
-    'CAVEATS',
     'SEE ALSO', 'ORIGINAL SEE ALSO',
 
-    # credits
+
+    # standards, from bsd
+    'STANDARDS',
+
+
+    # history
+    'HISTORY', 'ORIGINAL HISTORY',
+
+
+    # credits, authors, contributors, & copyright
     'CREDITS', 'ORIGINAL CREDITS',
     'THANKS', 'ORIGINAL THANKS',
 
-    # author, contributors, & copyright
     qr/^AUTHORS?/,
     qr/^ORIGINAL AUTHORS?/,
 
@@ -94,6 +119,12 @@ our $SORT_SPEC = [
     'COPYRIGHT AND LICENSE', 'ORIGINAL COPYRIGHT AND LICENSE',
     'COPYRIGHT', 'ORIGINAL COPYRIGHT',
     'LICENSE', 'ORIGINAL LICENSE',
+
+
+    # bugs/caveats
+    'BUGS', 'ORIGINAL BUGS',
+    'GOTCHAS',
+    'CAVEATS',
 ];
 
 sub meta {
@@ -129,7 +160,7 @@ Sort::Sub::pod_section_ala_perlancar - Sort POD sections (headings) PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.090 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-08-22.
+This document describes version 0.091 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-08-22.
 
 =head1 SYNOPSIS
 
@@ -180,14 +211,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sort-SubBu
 
 Source repository is at L<https://github.com/perlancar/perl-Sort-SubBundle-PERLANCAR>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-SubBundle-PERLANCAR>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Pod::Weaver::Plugin::PERLANCAR::SortSections>, which uses the sort
@@ -207,4 +230,12 @@ This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar <perlan
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-SubBundle-PERLANCAR>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
